Package: yulab.utils
Title: Supporting Functions for Packages Maintained by 'YuLab-SMU'
Version: 0.2.4
Authors@R: c(person("Guangchuang", "Yu", email = "guangchuangyu@gmail.com", role = c("aut", "cre"), comment = c(ORCID = "0000-0002-6485-8781")))
Description: Miscellaneous functions commonly used by 'YuLab-SMU'.
Depends: R (>= 4.2.0)
Imports: cli, digest, fs, methods, rappdirs, rlang, tools, utils
Suggests: httr2, jsonlite, openssl, R.utils, testthat (>= 3.0.0)
ByteCompile: true
License: Artistic-2.0
URL: https://yulab-smu.top/
BugReports: https://github.com/YuLab-SMU/yulab.utils/issues
Encoding: UTF-8
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-02-01 23:57:30 UTC; HUAWEI
Author: Guangchuang Yu [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6485-8781>)
Maintainer: Guangchuang Yu <guangchuangyu@gmail.com>
Repository: CRAN
Date/Publication: 2026-02-02 06:30:02 UTC
Built: R 4.6.0; ; 2026-04-26 10:56:42 UTC; unix
