# Generated by roxygen2: do not edit by hand

S3method("[",chunked_array)
S3method(as.vector,chunked_array)
S3method(is.character,chunked_array)
S3method(is.numeric,chunked_array)
S3method(length,chunked_array)
S3method(print,chunked_array)
S3method(print,exec)
export(Biocpkg)
export(CRANpkg)
export(Githubpkg)
export(auto_set_regexpr_style)
export(c2)
export(cache_list_items)
export(cache_load)
export(cache_save)
export(cache_size)
export(check_directory)
export(check_file)
export(check_input)
export(check_packages)
export(check_pkg)
export(check_range)
export(combinations)
export(download_yulab_file)
export(exec)
export(get_cache)
export(get_cache_element)
export(get_cache_item)
export(get_dependencies)
export(get_fun_from_pkg)
export(has_internet)
export(initial_cache)
export(initial_cache_item)
export(install_zip)
export(install_zip_gh)
export(is.installed)
export(load_OrgDb)
export(ls2df)
export(mat2df)
export(mat2list)
export(mypkg)
export(o)
export(packageTitle)
export(parse_ratio)
export(pload)
export(prune_cache_item)
export(quiet)
export(rbindlist)
export(read.cb)
export(rm_cache)
export(rm_cache_item)
export(scale_range)
export(scihub_dl)
export(set_PCRE)
export(set_TRE)
export(set_regexpr_style)
export(show_in_excel)
export(str_detect)
export(str_ends)
export(str_extract)
export(str_starts)
export(str_wrap)
export(update_cache_item)
export(use_perl)
export(user_dir)
export(with_cache)
export(yread)
export(yread_tsv)
export(yulab_abort)
export(yulab_inform)
export(yulab_msg)
export(yulab_warn)
importFrom(cli,cli_h2)
importFrom(digest,digest)
importFrom(fs,path_join)
importFrom(methods,is)
importFrom(rappdirs,user_data_dir)
importFrom(rlang,abort)
importFrom(rlang,as_name)
importFrom(rlang,check_installed)
importFrom(rlang,enquo)
importFrom(rlang,inform)
importFrom(rlang,warn)
importFrom(stats,setNames)
importFrom(tools,package_dependencies)
importFrom(utils,bibentry)
importFrom(utils,capture.output)
importFrom(utils,combn)
importFrom(utils,download.file)
importFrom(utils,getFromNamespace)
importFrom(utils,modifyList)
importFrom(utils,packageDescription)
importFrom(utils,read.delim)
importFrom(utils,read.table)
