% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/error-utils.r
\name{check_directory}
\alias{check_directory}
\title{Check if directory exists and is accessible}
\usage{
check_directory(
  path,
  create_if_missing = FALSE,
  check_write_permission = TRUE,
  arg_name = "directory"
)
}
\arguments{
\item{path}{Directory path}

\item{create_if_missing}{Whether to create directory if it doesn't exist}

\item{check_write_permission}{Whether to verify write permissions}

\item{arg_name}{Name of the argument for error messages}
}
\value{
Invisible TRUE if valid, throws error otherwise
}
\description{
Validates directory existence and accessibility with options to create if missing
}
\seealso{
Other validate-utils: 
\code{\link{check_file}()},
\code{\link{check_input}()},
\code{\link{check_packages}()},
\code{\link{check_range}()}
}
\concept{validate-utils}
