% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/quiet.r
\name{quiet}
\alias{quiet}
\title{quiet}
\usage{
quiet(x)
}
\arguments{
\item{x}{some code}
}
\value{
the result of \code{x}
}
\description{
Suppress messages and output from \code{x}
}
