% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/error-utils.r
\name{check_file}
\alias{check_file}
\title{Handle file operations with proper error messages}
\usage{
check_file(path, operation = "read", must_exist = TRUE)
}
\arguments{
\item{path}{File path}

\item{operation}{Operation being performed (read, write, etc.)}

\item{must_exist}{Whether the file must exist}
}
\value{
Invisible TRUE if operation can proceed, throws error otherwise
}
\description{
Enhanced file validation with comprehensive checks and better error messages
}
\seealso{
Other validate-utils: 
\code{\link{check_directory}()},
\code{\link{check_input}()},
\code{\link{check_packages}()},
\code{\link{check_range}()}
}
\concept{validate-utils}
