% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/error-utils.r
\name{check_range}
\alias{check_range}
\title{Check if value is within specified range}
\usage{
check_range(x, min = NULL, max = NULL, inclusive = TRUE, arg_name = "value")
}
\arguments{
\item{x}{Numeric value to check}

\item{min}{Minimum allowed value (optional)}

\item{max}{Maximum allowed value (optional)}

\item{inclusive}{Whether bounds are inclusive (default: TRUE)}

\item{arg_name}{Name of the argument for error messages}
}
\value{
Invisible TRUE if valid, throws error otherwise
}
\description{
Validates that a numeric value falls within the specified range
}
\seealso{
Other validate-utils: 
\code{\link{check_directory}()},
\code{\link{check_file}()},
\code{\link{check_input}()},
\code{\link{check_packages}()}
}
\concept{validate-utils}
