% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/error-utils.r
\name{yulab_abort}
\alias{yulab_abort}
\alias{yulab_warn}
\alias{yulab_inform}
\title{Standardized error handling}
\usage{
yulab_abort(message, class = "yulab_error", ...)

yulab_warn(message, class = "yulab_warning", ...)

yulab_inform(message, class = "yulab_info", ...)
}
\arguments{
\item{message}{Message string}

\item{class}{Custom class for categorization}

\item{...}{Additional context}
}
\value{
No return value
}
\description{
Provides \code{rlang}-based wrappers for messaging: \code{yulab_abort()}, \code{yulab_warn()},
and \code{yulab_inform()}.
}
\concept{messages}
