% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/error-utils.r
\name{check_packages}
\alias{check_packages}
\alias{check_pkg}
\title{Check if required packages are installed with informative errors}
\usage{
check_packages(packages, reason = "for this functionality")

check_pkg(packages, reason = "for this functionality")
}
\arguments{
\item{packages}{Character vector of package names}

\item{reason}{Reason why these packages are needed}
}
\value{
Invisible TRUE if all packages are available, throws error otherwise
}
\description{
Enhanced package checking with better error messages and validation
}
\seealso{
Other validate-utils: 
\code{\link{check_directory}()},
\code{\link{check_file}()},
\code{\link{check_input}()},
\code{\link{check_range}()}
}
\concept{validate-utils}
